import { Component } from '@angular/core';
import { FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { FormBuilder } from '@angular/forms';
import { Router } from '@angular/router';
import { FormGroup } from '@angular/forms';
import { User } from '../../model/User';
import { RegisterService } from '../../services/register.service';
import { LocalStorageService } from '../../services/localstorage.service';

@Component({
  selector: 'app-register-page',
  imports: [FormsModule, ReactiveFormsModule],
  templateUrl: './register-page.component.html',
  styleUrl: './register-page.component.css',
})
export class RegisterPageComponent {
  userForm: FormGroup;
  user: User = { login: '', password: '' };
  errorMessage: string = '';

  constructor(
    private registerService: RegisterService,
    private fb: FormBuilder,
    private localStorageService: LocalStorageService,
    private router: Router
  ) {
    this.userForm = this.fb.group(
      {
        login: [
          this.user.login,
          [Validators.required, Validators.minLength(6)],
        ],
        password: [
          this.user.password,
          [Validators.required, Validators.minLength(6)],
        ],
        verifyPassword: ['', [Validators.required]],
      },
      { validator: this.passwordMatchValidator }
    );
  }

  passwordMatchValidator(formGroup: FormGroup) {
    const password = formGroup.get('password')?.value;
    const verifyPassword = formGroup.get('verifyPassword')?.value;

    return password === verifyPassword ? null : { mismatch: true };
  }

  public register() {
    if (this.userForm.invalid) {
      this.errorMessage = 'Veuillez remplir tous les champs';
      return;
    }

    this.user.login = this.userForm.value.login;
    this.user.password = this.userForm.value.password;

    this.registerService
      .register(this.user.login, this.user.password)
      .subscribe({
        next: (response) => {
          console.log('Connexion OK: ', response);
          this.localStorageService.setToken(response.access_token);
          this.closeModal();
          setTimeout(() => {
            this.router.navigate(['/map']);
            window.location.reload();
          }, 500);
        },
        error: (response) => {
          console.log('Connexion KO: ', response.error.detail);
          this.errorMessage = response.error.detail;
        },
      });
  }

  private closeModal() {
    const modal = document.getElementById('close-register-modal');
    if (modal) {
      modal.click();
    }
  }
}
